@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009 Nokia Corporation, all rights reserved.
+ * Copyright (C) 2009 Nokia Corporation.
  *
  * Author: Zeeshan Ali (Khattak) <zeeshanak@gnome.org>
  *                               <zeeshan.ali@nokia.com>
@@ -58,16 +58,28 @@ G_DEFINE_TYPE (GUPnPNetworkManager,
 
 typedef enum
 {
-        NM_DEVICE_STATE_UNKNOWN,
-        NM_DEVICE_STATE_UNMANAGED,
-        NM_DEVICE_STATE_UNAVAILABLE,
-        NM_DEVICE_STATE_DISCONNECTED,
-        NM_DEVICE_STATE_PREPARE,
-        NM_DEVICE_STATE_CONFIG,
-        NM_DEVICE_STATE_NEED_AUTH,
-        NM_DEVICE_STATE_IP_CONFIG,
-        NM_DEVICE_STATE_ACTIVATED,
-        NM_DEVICE_STATE_FAILED
+        NM_DEVICE_STATE_UNKNOWN = 0,
+        NM_OLD_DEVICE_STATE_UNMANAGED = 1,
+        NM_OLD_DEVICE_STATE_UNAVAILABLE = 2,
+        NM_OLD_DEVICE_STATE_DISCONNECTED = 3,
+        NM_OLD_DEVICE_STATE_PREPARE = 4,
+        NM_OLD_DEVICE_STATE_CONFIG = 5,
+        NM_OLD_DEVICE_STATE_NEED_AUTH = 6,
+        NM_OLD_DEVICE_STATE_IP_CONFIG = 7,
+        NM_OLD_DEVICE_STATE_ACTIVATED = 8,
+        NM_OLD_DEVICE_STATE_FAILED = 9,
+        NM_DEVICE_STATE_UNMANAGED = 10,
+        NM_DEVICE_STATE_UNAVAILABLE = 20,
+        NM_DEVICE_STATE_DISCONNECTED = 30,
+        NM_DEVICE_STATE_PREPARE = 40,
+        NM_DEVICE_STATE_CONFIG = 50,
+        NM_DEVICE_STATE_NEED_AUTH = 60,
+        NM_DEVICE_STATE_IP_CONFIG = 70,
+        NM_DEVICE_STATE_IP_CHECK = 80,
+        NM_DEVICE_STATE_SECONDARIES = 90,
+        NM_DEVICE_STATE_ACTIVATED = 100,
+        NM_DEVICE_STATE_DEACTIVATING = 110,
+        NM_DEVICE_STATE_FAILED = 120
 } NMDeviceState;
 
 typedef enum
@@ -75,8 +87,12 @@ typedef enum
         NM_DEVICE_TYPE_UNKNOWN,
         NM_DEVICE_TYPE_ETHERNET,
         NM_DEVICE_TYPE_WIFI,
-        NM_DEVICE_TYPE_GSM,
-        NM_DEVICE_TYPE_CDMA,
+        NM_OLD_DEVICE_TYPE_GSM,
+        NM_OLD_DEVICE_TYPE_CDMA,
+        NM_DEVICE_TYPE_BT,
+        NM_DEVICE_TYPE_OLPC_MESH,
+        NM_DEVICE_TYPE_WIMAX,
+        NM_DEVICE_TYPE_MODEM
 } NMDeviceType;
 
 typedef struct
@@ -153,12 +169,13 @@ create_loopback_context (gpointer data)
                       "port", &port,
                       NULL);
 
-        context = g_object_new (GUPNP_TYPE_CONTEXT,
-                                "main-context", main_context,
-                                "interface", LOOPBACK_IFACE,
-                                "port", port,
-                                "error", &error,
-                                NULL);
+        context = g_initable_new (GUPNP_TYPE_CONTEXT,
+                                  NULL,
+                                  &error,
+                                  "main-context", main_context,
+                                  "interface", LOOPBACK_IFACE,
+                                  "port", port,
+                                  NULL);
         if (error) {
                 g_warning ("Error creating GUPnP context: %s\n",
                            error->message);
@@ -213,13 +230,14 @@ create_context_for_device (NMDevice *nm_device)
                 }
         }
 
-        nm_device->context = g_object_new (GUPNP_TYPE_CONTEXT,
-                                           "main-context", main_context,
-                                           "interface", iface,
-                                           "network", ssid,
-                                           "port", port,
-                                           "error", &error,
-                                           NULL);
+        nm_device->context = g_initable_new (GUPNP_TYPE_CONTEXT,
+                                             NULL,
+                                             &error,
+                                             "main-context", main_context,
+                                             "interface", iface,
+                                             "network", ssid,
+                                             "port", port,
+                                             NULL);
         g_free (iface);
         g_free (ssid);
 
@@ -335,7 +353,8 @@ on_device_signal (GDBusProxy *proxy,
         nm_device = (NMDevice *) user_data;
         g_variant_get_child (parameters, 0, "u", &new_state);
 
-        if (new_state == NM_DEVICE_STATE_ACTIVATED)
+        if (new_state == NM_OLD_DEVICE_STATE_ACTIVATED ||
+            new_state == NM_DEVICE_STATE_ACTIVATED)
                 on_device_activated (nm_device);
         else if (nm_device->context != NULL) {
                 /* For all other states we just destroy the context */
@@ -381,7 +400,8 @@ use_new_device (GUPnPNetworkManager *manager,
         state = g_variant_get_uint32 (value);
         g_variant_unref (value);
 
-        if (state == NM_DEVICE_STATE_ACTIVATED)
+        if (state == NM_OLD_DEVICE_STATE_ACTIVATED ||
+            state == NM_DEVICE_STATE_ACTIVATED)
                 on_device_activated (nm_device);
 }
 
