@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009 Nokia Corporation, all rights reserved.
+ * Copyright (C) 2009 Nokia Corporation.
  *
  * Author: Zeeshan Ali (Khattak) <zeeshanak@gnome.org>
  *                               <zeeshan.ali@nokia.com>
@@ -70,7 +70,7 @@ typedef struct {
 } GUPnPNetworkManagerClass;
 
 gboolean
-gupnp_network_manager_is_available                      (void);
+gupnp_network_manager_is_available                      (GMainContext *main_context);
 
 G_END_DECLS
 
