@@ -65,6 +65,7 @@ gupnp_root_device_finalize (GObject *object)
 
         device = GUPNP_ROOT_DEVICE (object);
 
+        g_object_unref (device->priv->description_doc);
         g_free (device->priv->description_path);
         g_free (device->priv->description_dir);
         g_free (device->priv->relative_location);
@@ -87,11 +88,6 @@ gupnp_root_device_dispose (GObject *object)
                 device->priv->group = NULL;
         }
 
-        if (device->priv->description_doc) {
-                g_object_unref (device->priv->description_doc);
-                device->priv->description_doc = NULL;
-        }
-
         /* Call super */
         object_class = G_OBJECT_CLASS (gupnp_root_device_parent_class);
         object_class->dispose (object);
@@ -408,7 +404,11 @@ gupnp_root_device_constructor (GType                  type,
         device = GUPNP_ROOT_DEVICE (object);
 
         /* Generate location relative to HTTP root */
-        device->priv->relative_location = g_strdup_printf ("RootDevice%p.xml",                                                             object);
+        udn = gupnp_device_info_get_udn (GUPNP_DEVICE_INFO (device));
+        if (udn && strstr (udn, "uuid:") == udn)
+                device->priv->relative_location = g_strdup_printf ("%s.xml", udn + 5);
+        else
+                device->priv->relative_location = g_strdup_printf ("RootDevice%p.xml", device);
 
         relative_location = g_strjoin (NULL,
                                        "/",
@@ -445,7 +445,6 @@ gupnp_root_device_constructor (GType                  type,
         device->priv->group = gssdp_resource_group_new (GSSDP_CLIENT (context));
 
         /* Add services and devices to resource group */
-        udn = gupnp_device_info_get_udn (GUPNP_DEVICE_INFO (device));
         usn = g_strdup_printf ("%s::upnp:rootdevice", (const char *) udn);
         gssdp_resource_group_add_resource_simple (device->priv->group,
                                                   "upnp:rootdevice",
@@ -457,6 +456,7 @@ gupnp_root_device_constructor (GType                  type,
 
  DONE:
         /* Cleanup */
+        g_free (desc_path);
         g_free (location);
 
         return object;
