@@ -52,6 +52,8 @@ gupnp_service_proxy_get_type (void) G_GNUC_CONST;
                  GUPnPServiceProxyClass))
 
 typedef struct _GUPnPServiceProxyPrivate GUPnPServiceProxyPrivate;
+typedef struct _GUPnPServiceProxy GUPnPServiceProxy;
+typedef struct _GUPnPServiceProxyClass GUPnPServiceProxyClass;
 
 /**
  * GUPnPServiceProxy:
@@ -59,13 +61,13 @@ typedef struct _GUPnPServiceProxyPrivate GUPnPServiceProxyPrivate;
  * This struct contains private data only, and should be accessed using the
  * functions below.
  */
-typedef struct {
+struct _GUPnPServiceProxy {
         GUPnPServiceInfo parent;
 
         GUPnPServiceProxyPrivate *priv;
-} GUPnPServiceProxy;
+};
 
-typedef struct {
+struct _GUPnPServiceProxyClass {
         GUPnPServiceInfoClass parent_class;
 
         /* signals */
@@ -77,7 +79,7 @@ typedef struct {
         void (* _gupnp_reserved2) (void);
         void (* _gupnp_reserved3) (void);
         void (* _gupnp_reserved4) (void);
-} GUPnPServiceProxyClass;
+};
 
 /**
  * GUPnPServiceProxyAction
@@ -136,6 +138,18 @@ gupnp_service_proxy_send_action_hash
                                     GHashTable                     *in_hash,
                                     GHashTable                     *out_hash);
 
+
+gboolean
+gupnp_service_proxy_send_action_list (GUPnPServiceProxy *proxy,
+                                      const char        *action,
+                                      GError           **error,
+                                      GList             *in_names,
+                                      GList             *in_values,
+                                      GList             *out_names,
+                                      GList             *out_types,
+                                      GList            **out_values);
+
+
 GUPnPServiceProxyAction *
 gupnp_service_proxy_begin_action   (GUPnPServiceProxy              *proxy,
                                     const char                     *action,
@@ -151,6 +165,15 @@ gupnp_service_proxy_begin_action_valist
                                     gpointer                        user_data,
                                     va_list                         var_args);
 
+GUPnPServiceProxyAction *
+gupnp_service_proxy_begin_action_list
+                                   (GUPnPServiceProxy              *proxy,
+                                    const char                     *action,
+                                    GList                          *in_names,
+                                    GList                          *in_values,
+                                    GUPnPServiceProxyActionCallback callback,
+                                    gpointer                        user_data);
+
 GUPnPServiceProxyAction *
 gupnp_service_proxy_begin_action_hash
                                    (GUPnPServiceProxy              *proxy,
@@ -172,6 +195,15 @@ gupnp_service_proxy_end_action_valist
                                     GError                        **error,
                                     va_list                         var_args);
 
+gboolean
+gupnp_service_proxy_end_action_list
+                                  (GUPnPServiceProxy       *proxy,
+                                   GUPnPServiceProxyAction *action,
+                                   GError                  **error,
+                                   GList                   *out_names,
+                                   GList                   *out_types,
+                                   GList                  **out_values);
+
 gboolean
 gupnp_service_proxy_end_action_hash
                                    (GUPnPServiceProxy              *proxy,
